package cd.casic.ci.commons.commonapi.pojo;

import io.swagger.v3.oas.annotations.media.Schema;
import lombok.Data;

import java.util.List;

@Data
@Schema(title = "构建历史-分页数据包装模型")
public class BuildHistoryPage<T> {
    @Schema(title = "总记录行数", required = true)
    private final Long count;

    @Schema(title = "第几页", required = true)
    private final Integer page;

    @Schema(title = "每页多少条", required = true)
    private final Integer pageSize;

    @Schema(title = "总共多少页", required = true)
    private final Integer totalPages;

    @Schema(title = "数据", required = true)
    private final List<T> records;

    @Schema(title = "是否拥有下载构建的权限", required = true)
    private final Boolean hasDownloadPermission;

    @Schema(title = "最新的编排版本号", required = true)
    private final Integer pipelineVersion;

    public BuildHistoryPage(Integer page, Integer pageSize, Long count, List<T> records, 
                          Boolean hasDownloadPermission, Integer pipelineVersion) {
        this.count = count;
        this.page = page;
        this.pageSize = pageSize;
        this.totalPages = (int) Math.ceil(count.doubleValue() / pageSize);
        this.records = records;
        this.hasDownloadPermission = hasDownloadPermission;
        this.pipelineVersion = pipelineVersion;
    }
} 