/*
 * Tencent is pleased to support the open source community by making BK-CI 蓝鲸持续集成平台 available.
 *
 * Copyright (C) 2019 THL A29 Limited, a Tencent company.  All rights reserved.
 *
 * BK-CI 蓝鲸持续集成平台 is licensed under the MIT license.
 *
 * A copy of the MIT License is included in this file.
 *
 * ...
 */

package cd.casic.ci.commons.commonapi.pojo.agent;

import io.swagger.v3.oas.annotations.media.Schema;

import java.util.List;

@Schema(title = "心跳信息模型")
public class NewHeartbeatInfo {
    @Schema(title = "主版本")
    private String masterVersion;

    @Schema(title = "从属版本")
    private String slaveVersion;

    @Schema(title = "主机名")
    private String hostName;

    @Schema(title = "构建机模型")
    private String agentIp;

    @Schema(title = "并行任务计数")
    private int parallelTaskCount;

    @Schema(title = "构建机安装路径")
    private String agentInstallPath;

    @Schema(title = "启动者")
    private String startedUser;

    @Schema(title = "第三方构建信息列表")
    private List<ThirdPartyBuildInfo> taskList;

    @Schema(title = "Agent属性信息")
    private AgentPropsInfo props;

    @Schema(title = "构建机id")
    private Long agentId;

    @Schema(title = "项目id")
    private String projectId;

    @Schema(title = "心跳时间戳")
    private Long heartbeatTime;

    @Schema(title = "忙碌运行中任务数量")
    private int busyTaskSize = 0;

    @Schema(title = "docker并行任务计数")
    private Integer dockerParallelTaskCount;

    @Schema(title = "docker构建信息列表")
    private List<ThirdPartyDockerBuildInfo> dockerTaskList;

    @Schema(title = "忙碌运行docker中任务数量")
    private int dockerBusyTaskSize = 0;

    @Schema(title = "Agent退出的错误信息")
    private AgentErrorExitData errorExitData;

    public NewHeartbeatInfo(String masterVersion, String slaveVersion, String hostName, String agentIp,
                            int parallelTaskCount, String agentInstallPath, String startedUser,
                            List<ThirdPartyBuildInfo> taskList, AgentPropsInfo props, Long agentId,
                            String projectId, Long heartbeatTime, int busyTaskSize,
                            Integer dockerParallelTaskCount, List<ThirdPartyDockerBuildInfo> dockerTaskList,
                            int dockerBusyTaskSize, AgentErrorExitData errorExitData) {
        this.masterVersion = masterVersion;
        this.slaveVersion = slaveVersion;
        this.hostName = hostName;
        this.agentIp = agentIp;
        this.parallelTaskCount = parallelTaskCount;
        this.agentInstallPath = agentInstallPath;
        this.startedUser = startedUser;
        this.taskList = taskList;
        this.props = props;
        this.agentId = agentId;
        this.projectId = projectId;
        this.heartbeatTime = heartbeatTime;
        this.busyTaskSize = busyTaskSize;
        this.dockerParallelTaskCount = dockerParallelTaskCount;
        this.dockerTaskList = dockerTaskList;
        this.dockerBusyTaskSize = dockerBusyTaskSize;
        this.errorExitData = errorExitData;
    }

    public static NewHeartbeatInfo dummyHeartbeat(String projectId, Long agentId) {
        return new NewHeartbeatInfo(
                "",
                "",
                "",
                "",
                0,
                "",
                "",
                List.of(),
                new AgentPropsInfo("", null, null),
                agentId,
                projectId,
                System.currentTimeMillis(),
                0,
                0,
                List.of(),
                0,
                null
        );
    }

    // Getters and Setters
} 